@@ -61,8 +61,6 @@
 #define Pi_p2by3 2.1450293971110256000774441009412356
 #define log4 1.3862943611198906188344642429163531
 
-
-extern int newswitch; //temporay global variable to use the new LALSTPN
 static void q2eta(double q, double *eta);
 static void q2masses(double mc, double q, double *m1, double *m2);
 
@@ -158,24 +156,18 @@ double m1,m2,mc,eta,q,iota=0;
   }
   else
   {
-    if (LALInferenceCheckVariable(model->params,"asym_massratio")) {
-      q = *(REAL8 *)LALInferenceGetVariable(model->params,"asym_massratio");
+    if (LALInferenceCheckVariable(model->params,"q")) {
+      q = *(REAL8 *)LALInferenceGetVariable(model->params,"q");
       q2eta(q, &eta);
     }
     else
-      eta = *(REAL8*) LALInferenceGetVariable(model->params, "massratio");
+      eta = *(REAL8*) LALInferenceGetVariable(model->params, "eta");
     mc       = *(REAL8*) LALInferenceGetVariable(model->params, "chirpmass");
     mc2masses(mc, eta, &m1, &m2);
   }
 
-  LALInferenceFrame frame=LALINFERENCE_FRAME_RADIATION;
-  if (LALInferenceCheckVariable(model->params, "LALINFERENCE_FRAME"))
-    frame = *(LALInferenceFrame*) LALInferenceGetVariable(model->params, "LALINFERENCE_FRAME");
-  if(frame==LALINFERENCE_FRAME_RADIATION){
-    iota	= *(REAL8*) LALInferenceGetVariable(model->params, "inclination");	    /* inclination in radian */
-  } else if(frame==LALINFERENCE_FRAME_SYSTEM) {
-    iota = *(REAL8*) LALInferenceGetVariable(model->params, "theta_JN");     /* zenith angle between J and N in radians */
-  }
+  iota = acos(LALInferenceGetREAL8Variable(model->params, "costheta_jn"));     /* zenith angle between J and N in radians */
+
   double cosiota = cos(iota);
   double plusCoef  = 0.5 * (1.0 + cosiota*cosiota);
   double crossCoef = cosiota;
@@ -240,7 +232,7 @@ double m1,m2,mc,eta,q,iota=0;
     GSL_SET_COMPLEX(&h_i, amp * cos(Psi + shft * f - 2.*phic - LAL_PI_4), - amp * sin(Psi + shft * f - 2.*phic - LAL_PI_4));
 
     gsl_vector_complex_set(model->roq->hplus, i, gsl_complex_mul_real(h_i,plusCoef));
-    gsl_vector_complex_set(model->roq->hcross, i, gsl_complex_mul_real(gsl_complex_mul_imag(h_i,1.0),crossCoef));
+    gsl_vector_complex_set(model->roq->hcross, i, gsl_complex_mul_real(gsl_complex_mul_imag(h_i,-1.0),crossCoef));
 
   }
 	return;
@@ -259,12 +251,12 @@ double m1,m2,mc,eta,q;
     }
   else
     {
-      if (LALInferenceCheckVariable(model->params,"asym_massratio")) {
-        q = *(REAL8 *)LALInferenceGetVariable(model->params,"asym_massratio");
+      if (LALInferenceCheckVariable(model->params,"q")) {
+        q = *(REAL8 *)LALInferenceGetVariable(model->params,"q");
         q2eta(q, &eta);
       }
       else
-        eta = *(REAL8*) LALInferenceGetVariable(model->params, "massratio");
+        eta = *(REAL8*) LALInferenceGetVariable(model->params, "eta");
         mc       = *(REAL8*) LALInferenceGetVariable(model->params, "chirpmass");
       mc2masses(mc, eta, &m1, &m2);
     } 
@@ -475,10 +467,9 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
 /*   - "LAL_APPROXIMANT     Approximant;        Approximant                                                              */
 /*   - "LAL_PNORDER"        Phase PN order;     INT4                                                                     */
 /*   - "LAL_AMPORDER"       Amplitude PN order; INT4 OPTIONAL (-1)                                                       */
-/*   - "LALINFERENCE_FRAME" reference frame;    LALInferenceFrame OPTIONAL (LALINFERENCE_FRAME_RADIATION)                */
 /*   - "spinO"              Spin order;         LALSimInspiralSpinOrder OPTIONAL (LAL_SIM_INSPIRAL_SPIN_ORDER_DEFAULT)   */
 /*   - "tideO"              Tidal order;        LALSimInspiralTidalOrder OPTIONAL (LAL_SIM_INSPIRAL_TIDAL_ORDER_DEFAULT) */
-/*   - "fRef"               frequency at which the (frequency dependent) parameters are defined; REAL8 OPTIONAL (0.0)    */
+/*   - "f_ref"               frequency at which the (frequency dependent) parameters are defined; REAL8 OPTIONAL (0.0)    */
 /*   - "fLow"               lower frequency bound; REAL8 OPTIONAL (model->fLow)                                          */
 /*                                                                                                                       */
 /*   MASS PARAMETERS; either:                                                                                            */
@@ -486,30 +477,21 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
 /*      - "mass2"		        mass of object 1 in solar mass; REAL8								                     */
 /*      OR                                                                                                               */
 /*      - "chirpmass"       chirpmass in solar mass; REAL8                                                               */
-/*      - "asym_massratio"  asymmetric mass ration m2/m1, 0<asym_massratio<1; REAL8                                      */
+/*      - "q"  asymmetric mass ratio m2/m1, 0<q<1; REAL8                                      */
 /*      OR                                                                                                               */
 /*      - "chirpmass"       chirpmass in solar mass; REAL8                                                               */
-/*      - "massratio"       symmetric mass ratio (m1*m2)/(m1+m2)^2; REAL8                                                */
+/*      - "eta"             symmetric mass ratio (m1*m2)/(m1+m2)^2; REAL8                                                */
 /*                                                                                                                       */
 /*   ORIENTATION AND SPIN PARAMETERS                                                                                     */
 /*   - "phi0"               reference phase as per LALSimulation convention; REAL8                                       */
 /*   - "distance"           distance in Mpc                                                                              */
-/*   - if LALINFERENCE_FRAME == LALINFERENCE_FRAME_SYSTEM  (default)                                                     */
-/*      - "theta_JN");      zenith angle between J and N in radians;            REAL8                                    */
-/*      - "phi_JL");        azimuthal angle of L_N on its cone about J radians; REAL8                                    */
-/*      - "tilt_spin1");    zenith angle between S1 and LNhat in radians;       REAL8                                    */
-/*      - "tilt_spin2");    zenith angle between S2 and LNhat in radians;       REAL8                                    */
-/*      - "phi12");         difference in azimuthal angle between S1, S2 in radians;   REAL8                             */
-/*   - else if LALINFERENCE_FRAME == LALINFERENCE_FRAME_RADIATION                                                        */
-/*      - "inclination"	    inclination angle L.N in radians;                            REAL8                           */
-/*      - "theta_spin1"     polar angle of spin 1, default to the spin aligned case;     REAL8 OPTIONAL (inclination)    */
-/*      - "phi_spin1"       azimuthal angle of spin 1, default to the spin aligned case; REAL8  OPTIONAL (0.0)           */
-/*      - "theta_spin2"     polar angle of spin 2, default to the spin aligned case;     REAL8 OPTIONAL (inclination)    */
-/*      - "phi_spin2"       azimuthal angle of spin 1, default to the spin aligned case; REAL8  OPTIONAL (0.0)           */
-/*   - "a_spin1"            magnitude of spin 1 in general configuration, 0<a_spin1<1; REAL8 OPTIONAL (0.0)              */
-/*   - "a_spin2"            magnitude of spin 2 in general configuration, 0<a_spin1<1; REAL8 OPTIONAL (0.0)              */
-/*   - "spin1"              magnitude of spin 1 in aligned configuration, -1<spin1<1;  REAL8 OPTIONAL (0.0)              */
-/*   - "spin2"              magnitude of spin 2 in aligned configuration, -1<spin1<1;  REAL8 OPTIONAL (0.0)              */
+/*   - "costheta_jn");      cos of zenith angle between J and N in radians;            REAL8                                    */
+/*   - "phi_jl");        azimuthal angle of L_N on its cone about J radians; REAL8                                    */
+/*   - "tilt_spin1");    zenith angle between S1 and LNhat in radians;       REAL8                                    */
+/*   - "tilt_spin2");    zenith angle between S2 and LNhat in radians;       REAL8                                    */
+/*   - "phi12");         difference in azimuthal angle between S1, S2 in radians;   REAL8                             */
+/*   - "a_spin1"            magnitude of spin 1 in general configuration, -1<a_spin1<1; REAL8 OPTIONAL (0.0)              */
+/*   - "a_spin2"            magnitude of spin 2 in general configuration, -1<a_spin1<1; REAL8 OPTIONAL (0.0)              */
 /*                                                                                                                       */
 /*   OTHER PARAMETERS                                                                                                    */
 /*   - "lambda1"            tidal parameter of object 1; REAL8  OPTIONAL (0.0)                                           */
@@ -534,7 +516,6 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
   Approximant approximant = (Approximant) 0;
   INT4 order=-1;
   INT4 amporder;
-  LALInferenceFrame frame=LALINFERENCE_FRAME_SYSTEM;
 
   unsigned long	i;
   static int sizeWarning = 0;
@@ -545,11 +526,14 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
   REAL8TimeSeries *hcross=NULL; /**< x-polarization waveform [returned] */
   COMPLEX16FrequencySeries *hptilde=NULL, *hctilde=NULL;
   REAL8 mc;
-  REAL8 phi0, deltaT, m1, m2, spin1x=0.0, spin1y=0.0, spin1z=0.0, spin2x=0.0, spin2y=0.0, spin2z=0.0, f_low, f_start, distance, inclination;
+  REAL8 phi0, deltaT, m1, m2, f_low, f_start, distance, inclination;
   
   REAL8 *m1_p,*m2_p;
   REAL8 deltaF, f_max;
   
+  /* Sampling rate for time domain models */
+  deltaT = model->deltaT;
+  
   if (LALInferenceCheckVariable(model->params, "LAL_APPROXIMANT"))
     approximant = *(Approximant*) LALInferenceGetVariable(model->params, "LAL_APPROXIMANT");
   else {
@@ -572,23 +556,20 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
     amporder = *(INT4*) LALInferenceGetVariable(model->params, "LAL_AMPORDER");
   else
     amporder = -1;
+    
+  REAL8 f_ref = 100.0;
+  if (LALInferenceCheckVariable(model->params, "f_ref")) f_ref = *(REAL8 *)LALInferenceGetVariable(model->params, "f_ref");
 
-  if (LALInferenceCheckVariable(model->params, "LALINFERENCE_FRAME"))
-    frame = *(LALInferenceFrame*) LALInferenceGetVariable(model->params, "LALINFERENCE_FRAME");
-
-  REAL8 fRef = 100.0;
-  if (LALInferenceCheckVariable(model->params, "fRef")) fRef = *(REAL8 *)LALInferenceGetVariable(model->params, "fRef");
-
-  REAL8 fTemp = fRef;
+  REAL8 fTemp = f_ref;
 
   if(LALInferenceCheckVariable(model->params,"chirpmass"))
     {
       mc  = *(REAL8*) LALInferenceGetVariable(model->params, "chirpmass");
-      if (LALInferenceCheckVariable(model->params,"asym_massratio")) {
-	REAL8 q = *(REAL8 *)LALInferenceGetVariable(model->params,"asym_massratio");
+      if (LALInferenceCheckVariable(model->params,"q")) {
+	REAL8 q = *(REAL8 *)LALInferenceGetVariable(model->params,"q");
 	q2masses(mc, q, &m1, &m2);
       } else {
-	REAL8 eta = *(REAL8*) LALInferenceGetVariable(model->params, "massratio");
+	REAL8 eta = *(REAL8*) LALInferenceGetVariable(model->params, "eta");
 	mc2masses(mc, eta, &m1, &m2);
       }
     }
@@ -604,111 +585,84 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
     }
 
   distance	= LALInferenceGetREAL8Variable(model->params,"distance")* LAL_PC_SI * 1.0e6;        /* distance (1 Mpc) in units of metres */
-
-  /* Default to spinless signals if spin amplitude are not present in model->params */
-  REAL8 a_spin1		= 0.0;
-  if(LALInferenceCheckVariable(model->params, "a_spin1"))    a_spin1   = *(REAL8*) LALInferenceGetVariable(model->params, "a_spin1");
-  REAL8 a_spin2    = 0.0;
-  if(LALInferenceCheckVariable(model->params, "a_spin2"))    a_spin2   = *(REAL8*) LALInferenceGetVariable(model->params, "a_spin2");
-
-  phi0		= *(REAL8*) LALInferenceGetVariable(model->params, "phase"); /* START phase as per lalsimulation convention*/
+  
+  phi0		= LALInferenceGetREAL8Variable(model->params, "phase"); /* START phase as per lalsimulation convention, radians*/
+  
+  /* Zenith angle between J and N in radians. Also known as inclination angle when spins are aligned */
+  REAL8 thetaJN = acos(LALInferenceGetREAL8Variable(model->params, "costheta_jn"));     /* zenith angle between J and N in radians */
 
   /* Check if fLow is a model parameter, otherwise use data structure definition */
-  if(LALInferenceCheckVariable(model->params, "fLow"))
-    f_low = *(REAL8*) LALInferenceGetVariable(model->params, "fLow");
+  if(LALInferenceCheckVariable(model->params, "flow"))
+    f_low = *(REAL8*) LALInferenceGetVariable(model->params, "flow");
   else
-    f_low = model->fLow /** 0.9 */;
+    f_low = model->fLow;
 
   f_start = fLow2fStart(f_low, amporder, approximant);
   f_max = 0.0; /* for freq domain waveforms this will stop at ISCO. Previously found using model->fHigh causes NaNs in waveform (see redmine issue #750)*/
 
-  int aligned_spins=0;
-  /* We first check if we are deadling with a spin-aligned only template, for which we use "spin1" and "spin2" names */
-  if(LALInferenceCheckVariable(model->params, "spin1")){
-    spin1z= *(REAL8*) LALInferenceGetVariable(model->params, "spin1");
-    spin1x=0.0;
-    spin1y=0.0;
-    aligned_spins+=1;
-  }
-  if(LALInferenceCheckVariable(model->params, "spin2")){
-    spin2z= *(REAL8*) LALInferenceGetVariable(model->params, "spin2");
-    spin2x=0.0;
-    spin2y=0.0;
-    aligned_spins+=1;
-  }
+  /* ==== SPINS ==== */
+  /* We will default to spinless signal and then add in the spin components if required */
+  /* If there are non-aligned spins, we must convert between the System Frame coordinates
+   * and the cartestian coordinates */
 
-  /* Set inclination to something sensible now, because for spin aligned we won't enter in the blocks below, where theta_JN or inclination
-   *  are set for no-spin or precessing spins. We can set inclination to either theta_JN or iota, as for aligned spins they are the same,
-   * while for frecessing spins they will be eventually overwritten to the right value here below  */
-  if (frame==LALINFERENCE_FRAME_SYSTEM)
-      inclination       = *(REAL8*) LALInferenceGetVariable(model->params, "theta_JN");           /* inclination in radian */
+  /* The cartesian spin coordinates (default 0), as passed to LALSimulation */
+  REAL8 spin1x = 0.0;
+  REAL8 spin1y = 0.0;
+  REAL8 spin1z = 0.0;
+  REAL8 spin2x = 0.0;
+  REAL8 spin2y = 0.0;
+  REAL8 spin2z = 0.0;
+  
+  /* System frame coordinates as used for jump proposals */
+  REAL8 a_spin1 = 0.0;  /* Magnitude of spin1 */
+  REAL8 a_spin2 = 0.0;  /* Magnitude of spin2 */
+  REAL8 phiJL  = 0.0;  /* azimuthal angle of L_N on its cone about J radians */ 
+  REAL8 tilt1   = 0.0;  /* zenith angle between S1 and LNhat in radians */
+  REAL8 tilt2   = 0.0;  /* zenith angle between S2 and LNhat in radians */
+  REAL8 phi12   = 0.0;  /* difference in azimuthal angle btwn S1, S2 in radians */
+
+  /* Now check if we have spin amplitudes */
+  if(LALInferenceCheckVariable(model->params, "a_spin1"))    a_spin1   = *(REAL8*) LALInferenceGetVariable(model->params, "a_spin1");
+  if(LALInferenceCheckVariable(model->params, "a_spin2"))    a_spin2   = *(REAL8*) LALInferenceGetVariable(model->params, "a_spin2");
+
+  /* Check if we have spin angles too */
+  if(LALInferenceCheckVariable(model->params, "phi_jl"))
+      phiJL = LALInferenceGetREAL8Variable(model->params, "phi_jl");
+  if(LALInferenceCheckVariable(model->params, "tilt_spin1"))
+      tilt1 = LALInferenceGetREAL8Variable(model->params, "tilt_spin1");
+  if(LALInferenceCheckVariable(model->params, "tilt_spin2"))
+      tilt2 = LALInferenceGetREAL8Variable(model->params, "tilt_spin2");
+  if(LALInferenceCheckVariable(model->params, "phi12"))
+      phi12 = LALInferenceGetREAL8Variable(model->params, "phi12");
+
+  /* If we have tilt angles zero, then the spins are aligned and we just set the z component */
+  /* However, if the waveform supports precession then we still need to get the right coordinate components */
+  SpinSupport spin_support=XLALSimInspiralGetSpinSupportFromApproximant(approximant);
+  if(tilt1==0.0 && tilt2==0.0 && (spin_support==LAL_SIM_INSPIRAL_SPINLESS || spin_support==LAL_SIM_INSPIRAL_ALIGNEDSPIN))
+  {
+      spin1z=a_spin1;
+      spin2z=a_spin2;
+      inclination = thetaJN; /* Inclination angle is just thetaJN */
+  }
   else
-      inclination       = *(REAL8*) LALInferenceGetVariable(model->params, "inclination");           /* inclination in radian */
-
-  if (aligned_spins==0){
-    /* Template is not spin-aligned only.
-     * Set the all other spins variables (that is an overkill. We can just check if there are spins in the first place, and if there aren't don't bother calculating them (they'll be zero) ) */
-    REAL8 phiJL=0.0;
-    REAL8 tilt1=0.0;
-    REAL8 tilt2=0.0;
-    REAL8 phi12=0.0;
-    if(frame==LALINFERENCE_FRAME_SYSTEM) {
-       /* IMPORTANT NOTE: default to spin aligned case (i.e. tilt1=tilt2=0) if no angles are provided for the spins.
-       * If you change this, must also change LALInferenceInitCBC.c
-       */
-       REAL8 thetaJN = *(REAL8*) LALInferenceGetVariable(model->params, "theta_JN");     /* zenith angle between J and N in radians */
-       if(LALInferenceCheckVariable(model->params, "phi_JL"))
-           phiJL = *(REAL8*) LALInferenceGetVariable(model->params, "phi_JL");     /* azimuthal angle of L_N on its cone about J radians */
-       if(LALInferenceCheckVariable(model->params, "tilt_spin1"))
-           tilt1 = *(REAL8*) LALInferenceGetVariable(model->params, "tilt_spin1");     /* zenith angle between S1 and LNhat in radians */
-       if(LALInferenceCheckVariable(model->params, "tilt_spin2"))
-           tilt2 = *(REAL8*) LALInferenceGetVariable(model->params, "tilt_spin2");     /* zenith angle between S2 and LNhat in radians */
-       if(LALInferenceCheckVariable(model->params, "phi12"))
-           phi12 = *(REAL8*) LALInferenceGetVariable(model->params, "phi12");      /* difference in azimuthal angle btwn S1, S2 in radians */
-
-      /* The transformation function doesn't know fLow, so fRef==0 isn't interpretted as a request to use the starting frequency for reference. */
+  {   /* Template is not aligned-spin only. */
+      /* Set all the other spin components according to the angles we received above */
+      /* The transformation function doesn't know fLow, so f_ref==0 isn't interpretted as a request to use the starting frequency for reference. */
       if(fTemp==0.0)
         fTemp = f_start;
 
       XLAL_TRY(ret=XLALSimInspiralTransformPrecessingInitialConditions(
-            &inclination, &spin1x, &spin1y, &spin1z, &spin2x, &spin2y, &spin2z,
-            thetaJN, phiJL, tilt1, tilt2, phi12, a_spin1, a_spin2, m1*LAL_MSUN_SI, m2*LAL_MSUN_SI, fTemp), errnum);
+                    &inclination, &spin1x, &spin1y, &spin1z, &spin2x, &spin2y, &spin2z,
+                    thetaJN, phiJL, tilt1, tilt2, phi12, a_spin1, a_spin2, m1*LAL_MSUN_SI, m2*LAL_MSUN_SI, fTemp), errnum);
       if (ret == XLAL_FAILURE)
       {
         XLALPrintError(" ERROR in XLALSimInspiralTransformPrecessingInitialConditions(): error converting angles. errnum=%d\n",errnum );
         return;
       }
-    }
-    else if(frame==LALINFERENCE_FRAME_RADIATION){
-      /* IMPORTANT NOTE: default to spin aligned case (i.e. theta1=theta2=iota) if no angles are provided for the spins.
-       * If you change this, must also change LALInferenceInitCBC.c
-       */
-      inclination	= *(REAL8*) LALInferenceGetVariable(model->params, "inclination");	    /* inclination in radian */
-      REAL8 theta_spin1	= inclination;
-      if(LALInferenceCheckVariable(model->params, "theta_spin1"))	theta_spin1	= *(REAL8*) LALInferenceGetVariable(model->params, "theta_spin1");
-      REAL8 phi_spin1		= 0.0;
-      if(LALInferenceCheckVariable(model->params, "phi_spin1"))	phi_spin1	= *(REAL8*) LALInferenceGetVariable(model->params, "phi_spin1");
-      REAL8 theta_spin2	= inclination;
-      if(LALInferenceCheckVariable(model->params, "theta_spin2"))	theta_spin2	= *(REAL8*) LALInferenceGetVariable(model->params, "theta_spin2");
-      REAL8 phi_spin2		= 0.0;
-      if(LALInferenceCheckVariable(model->params, "phi_spin2"))	phi_spin2	= *(REAL8*) LALInferenceGetVariable(model->params, "phi_spin2");
-
-      /* These are the components of spins in the frame N || z */
-      spin1x = (a_spin1 * sin(theta_spin1) * cos(phi_spin1));
-      spin1y = (a_spin1 * sin(theta_spin1) * sin(phi_spin1));
-      spin1z = (a_spin1 * cos(theta_spin1));
-
-      spin2x = (a_spin2 * sin(theta_spin2) * cos(phi_spin2));
-      spin2y = (a_spin2 * sin(theta_spin2) * sin(phi_spin2));
-      spin2z = (a_spin2 * cos(theta_spin2));
-
-    }
-    else {
-        XLALPrintError("Error: unknown frame %i\n",frame);
-        XLAL_ERROR_VOID(XLAL_EFAULT);
-    }
   }
-	
+
+  
+  /* ==== TIDAL PARAMETERS ==== */  
   REAL8 lambda1 = 0.;
   if(LALInferenceCheckVariable(model->params, "lambda1")) lambda1 = *(REAL8*) LALInferenceGetVariable(model->params, "lambda1");
   REAL8 lambda2 = 0.;
@@ -723,17 +677,20 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
     LALInferenceLambdaTsEta2Lambdas(lambdaT,dLambdaT,sym_mass_ratio_eta,&lambda1,&lambda2);
   }
 
+
+  /* Only use GR templates */
   LALSimInspiralTestGRParam *nonGRparams = NULL;
   
-  deltaT = model->deltaT;
   
+
+  /* ==== Call the waveform generator ==== */
   if(model->domain == LAL_SIM_DOMAIN_FREQUENCY) {
     deltaF = model->deltaF;
     
 	XLAL_TRY(ret=XLALSimInspiralChooseFDWaveformFromCache(&hptilde, &hctilde, phi0,
             deltaF, m1*LAL_MSUN_SI, m2*LAL_MSUN_SI, spin1x, spin1y, spin1z,
-            spin2x, spin2y, spin2z, f_start, f_max, fRef, distance, inclination,lambda1, lambda2, model->waveFlags, nonGRparams, amporder, order,
-            approximant,model->waveformCache), errnum);
+            spin2x, spin2y, spin2z, f_start, f_max, f_ref, distance, inclination,lambda1, lambda2, model->waveFlags, nonGRparams, amporder, order,
+            approximant,model->waveformCache, NULL), errnum);
 
 	if (hptilde==NULL || hptilde->data==NULL || hptilde->data->data==NULL ) {
 	  XLALPrintError(" ERROR in LALInferenceTemplateXLALSimInspiralChooseWaveform(): encountered unallocated 'hptilde'.\n");
@@ -774,7 +731,7 @@ void LALInferenceTemplateXLALSimInspiralChooseWaveform(LALInferenceModel *model)
 
     XLAL_TRY(ret=XLALSimInspiralChooseTDWaveformFromCache(&hplus, &hcross, phi0, deltaT,
             m1*LAL_MSUN_SI, m2*LAL_MSUN_SI, spin1x, spin1y, spin1z,
-            spin2x, spin2y, spin2z, f_start, fRef, distance,
+            spin2x, spin2y, spin2z, f_start, f_ref, distance,
             inclination, lambda1, lambda2, model->waveFlags, nonGRparams,
             amporder, order, approximant,model->waveformCache), errnum);
     XLALSimInspiralDestroyTestGRParam(nonGRparams);
