@@ -91,6 +91,10 @@
 
 #include "logaddexp.h"
 
+#ifndef _OPENMP
+#define omp ignore
+#endif
+
 
 /* Storage for old GSL error handler. */
 static gsl_error_handler_t *old_handler;
@@ -698,7 +702,7 @@ double *bayestar_sky_map_toa_phoa_snr(
         /* Restore old error handler. */
         gsl_set_error_handler(old_handler);
 
-        /* Sort pixels by descending log posterior. */
+        /* Sort pixels by ascending posterior probability. */
         adaptive_sky_map_sort(map);
 
         /* If we have reached order=11 (nside=2048), stop. */
